Class: DefraRubyGovpay::Configuration
- Inherits:
-
Object
- Object
- DefraRubyGovpay::Configuration
- Defined in:
- lib/defra_ruby_govpay/configuration.rb
Overview
The Configuration class is responsible for storing configurable settings for the DefraRubyGovpay module. You can set different options like API tokens, host preferences, and other necessary configurations here.
Instance Attribute Summary collapse
-
#back_office_webhook_signing_secret ⇒ Object
Returns the value of attribute back_office_webhook_signing_secret.
-
#front_office_webhook_signing_secret ⇒ Object
Returns the value of attribute front_office_webhook_signing_secret.
-
#govpay_back_office_api_token ⇒ Object
Returns the value of attribute govpay_back_office_api_token.
-
#govpay_front_office_api_token ⇒ Object
Returns the value of attribute govpay_front_office_api_token.
-
#govpay_url ⇒ Object
Returns the value of attribute govpay_url.
-
#logger ⇒ Object
Returns the value of attribute logger.
Instance Attribute Details
#back_office_webhook_signing_secret ⇒ Object
Returns the value of attribute back_office_webhook_signing_secret.
8 9 10 |
# File 'lib/defra_ruby_govpay/configuration.rb', line 8 def back_office_webhook_signing_secret @back_office_webhook_signing_secret end |
#front_office_webhook_signing_secret ⇒ Object
Returns the value of attribute front_office_webhook_signing_secret.
8 9 10 |
# File 'lib/defra_ruby_govpay/configuration.rb', line 8 def front_office_webhook_signing_secret @front_office_webhook_signing_secret end |
#govpay_back_office_api_token ⇒ Object
Returns the value of attribute govpay_back_office_api_token.
8 9 10 |
# File 'lib/defra_ruby_govpay/configuration.rb', line 8 def govpay_back_office_api_token @govpay_back_office_api_token end |
#govpay_front_office_api_token ⇒ Object
Returns the value of attribute govpay_front_office_api_token.
8 9 10 |
# File 'lib/defra_ruby_govpay/configuration.rb', line 8 def govpay_front_office_api_token @govpay_front_office_api_token end |
#govpay_url ⇒ Object
Returns the value of attribute govpay_url.
8 9 10 |
# File 'lib/defra_ruby_govpay/configuration.rb', line 8 def govpay_url @govpay_url end |
#logger ⇒ Object
Returns the value of attribute logger.
8 9 10 |
# File 'lib/defra_ruby_govpay/configuration.rb', line 8 def logger @logger end |